sqlmesh.core.config API documentation

Edit on GitHub

# sqlmesh.core.config

View Source

     1from sqlmesh.core.config.categorizer import AutoCategorizationMode, CategorizerConfig
     2from sqlmesh.core.config.connection import (
     3    BigQueryConnectionConfig,
     4    ConnectionConfig,
     5    DatabricksConnectionConfig,
     6    DatabricksSparkSessionConnectionConfig,
     7    DatabricksSQLConnectionConfig,
     8    DuckDBConnectionConfig,
     9    RedshiftConnectionConfig,
    10    SnowflakeConnectionConfig,
    11)
    12from sqlmesh.core.config.loader import load_config_from_paths
    13from sqlmesh.core.config.model import ModelDefaultsConfig
    14from sqlmesh.core.config.root import Config
    15from sqlmesh.core.config.scheduler import AirflowSchedulerConfig, BuiltInSchedulerConfig